.. highlight:: shell




.. _sec-installation:

Installation
------------------

Recommended method
^^^^^^^^^^^^^^^^^^

1. `Install docker <https://docs.docker.com/get-docker/>`_ on your machine (if on Linux, check the :doc:`additional installation steps <installation_linux>`)
2. Install *beobench* using:

        .. code-block:: console

                pip install beobench

Look at the :doc:`getting started guide <getting_started>` to run your first beobench experiment.

Directly from GitHub
^^^^^^^^^^^^^^^^^^^^

If you would like to get the truly latest (but not necessarily stable) version of beobench, you can replace the `pip install` command above with the following command:

.. code-block:: console

        pip install git+https://github.com/rdnfn/beobench

This will install the latest version directly from the master branch on GitHub.


Development environment
^^^^^^^^^^^^^^^^^^^^^^^

If you would like to contribute to beobench, use :doc:`this guide <dev_env>` to set up the full development environment.